@@ -17,18 +17,6 @@ $.extend(cw.cubes.brainomics, {
 	else{return null;}
     },
 
-    seeRelatedData: function(datatype, current_etype) {
-	var zipped = cw.cubes.brainomics.getCurrentRql();
-	if (zipped != null){
-	    var d = loadRemote(AJAX_BASE_URL, ajaxFuncArgs('filter_build_rql', null, zipped[0], zipped[1]));
-	    d.addCallback(function(result) {
-		    var rql = result[0];
-		    var dd = asyncRemoteExec('see_related_data', rql, datatype, current_etype);
-		    dd.addCallback(function(res) {window.location = res;});
-		    });
-	    };
-    },
-
     changeDownloadUrls: function(){
 	/* Change the download urls for facet rql */
 	var zipped = cw.cubes.brainomics.getCurrentRql();
@@ -39,5 +27,34 @@ $.extend(cw.cubes.brainomics, {
 			    this.href = BASE_URL+'?rql='+rql+'&vid='+this.id;
 			    console.log(BASE_URL+'?rql='+rql+'&vid='+this.id);});
 		    });
-	}
+	},
+
+    addDynamicFacet: function(selid){
+	/* Change the download urls for facet rql */
+        var $select = $("#" + selid);
+	var vocabulary = $select.val();
+	var zipped = cw.cubes.brainomics.getCurrentRql();
+        var extraparams = {};
+	extraparams['rql'] =  zipped[1][zipped[0].indexOf('baserql')];
+	extraparams['vid'] = 'dynamic-facet';
+	extraparams['vocabulary'] = vocabulary;
+	extraparams['dynamic-facet-id'] = selid;
+        var form = $select.parents('form')[0];
+        var d = $('#dynamic-facet-container').loadxhtml(AJAX_BASE_URL, ajaxFuncArgs('view', extraparams));
+        d.addCallback(function() {
+            $(CubicWeb).trigger('dynamics-facets-added', [form]);
+        });
+        return false;
+    },
+
+    updateFacets: function(event, form){
+        var facetargs = $(form).attr('cubicweb:facetargs');
+        if (facetargs != undefined) {
+            buildRQL.apply(null,  cw.evalJSON(facetargs));
+        }
+    }
+});
+
+$(document).ready(function() {
+    $(CubicWeb).bind('dynamics-facets-added', cw.cubes.brainomics.updateFacets);
 });
\ No newline at end of file
