@@ -31,11 +31,14 @@ from cubes.clinipath.schema import Biopsy, BiopsySample, CellCulture, BloodSampl
 
 
 # Diagnostic/TechnicalAnalysis
-for etype in ('QuestionnaireRun', 'Scan', 'GenomicMeasure',
-              'Biopsy', 'BiopsySample', 'CellCulture', 'BloodSample'):
+for etype in ('QuestionnaireRun', 'Scan', 'GenomicMeasure'):
     Diagnostic.add_relation(SubjectRelation(etype, cardinality='**'), name='based_on')
-    TechnicalAnalysis.add_relation(SubjectRelation(etype, composite='object',
-                                                   cardinality='**'), name='performed_on')
+    # No composite for TechnicalAnalysis (for container)
+    TechnicalAnalysis.add_relation(SubjectRelation(etype, cardinality='**'), name='performed_on')
+for etype in ('Biopsy', 'BiopsySample', 'CellCulture', 'BloodSample'):
+    Diagnostic.add_relation(SubjectRelation(etype, cardinality='**'), name='based_on')
+    # No composite for TechnicalAnalysis (for container)
+    TechnicalAnalysis.add_relation(SubjectRelation(etype, cardinality='**'), name='analysis_of_sample')
 for etype in ('QuestionnaireRun', 'Scan', 'GenomicMeasure', 'IHCMeasure'):
     ProcessingRun.add_relation(SubjectRelation(etype, cardinality='**'), name='inputs')
     ProcessingRun.add_relation(SubjectRelation(etype, cardinality='**'), name='outputs')
@@ -88,7 +91,7 @@ Subject.add_relation(SubjectRelation(('Biopsy', 'BiopsySample', 'CellCulture', '
                                      cardinality='?*', composite='subject'),
                      name='related_samples')
 GenomicMeasure.add_relation(SubjectRelation(('Biopsy', 'BiopsySample', 'CellCulture', 'BloodSample'),
-                                            cardinality='?*', inlined=True),
+                                            cardinality='**'),
                             name='measured_on_sample')
 for etype_class in (Biopsy, BiopsySample, CellCulture, BloodSample):
     etype_class.add_relation(SubjectRelation('MedicalTechnique', cardinality='?*',
