@@ -31,18 +31,23 @@ class BrainomicsContainersTC(CubicWebTC):
         req = self.request()
         create_subject_container_data(req)
 
+    def test_disjoint_container(self):
+        e1, r1 = SUBJECT_CONTAINER.structure(self.vreg.schema)
+        e2, r2 = ASSESSMENT_CONTAINER.structure(self.vreg.schema)
+        self.assertEqual(e1.intersection(e2), set())
+        self.assertEqual(r1.intersection(r2), set())
+
     def test_static_structure_subject(self):
         cfg = SUBJECT_CONTAINER
         self.assertEqual((frozenset(['related_diagnostics', 'related_therapies',
                                      'related_samples', 'related_biopsy',
-                                     'taken_in_therapy', 'performed_on',
+                                     'taken_in_therapy', 'evaluation_for',
                                      'admission_of', 'step_of', 'survival_of',
                                      'report_on']),
                           frozenset(['Diagnostic', 'Therapy', 'DrugTake',
-                                     'TechnicalAnalysis',
                                      'Biopsy', 'BiopsySample', 'BloodSample', 'CellCulture',
                                      'Admission', 'AdmissionStep',
-                                     'SurvivalData',
+                                     'SurvivalData', 'TherapyEvaluation',
                                      'AnatomicPathologyReport'])),
                          cfg.structure(self.vreg.schema))
 
@@ -51,9 +56,9 @@ class BrainomicsContainersTC(CubicWebTC):
         self.assertEqual(
             (frozenset(['results_files', 'configuration_files', 'uses', 'generates',
                         'measure', 'file_entries', 'assessment', 'questionnaire_run',
-                        'performed_on', 'related_measure', 'measure', 'has_data', 'comments']),
+                        'related_measure', 'measure', 'has_data', 'comments']),
              frozenset(['GenericMeasure', 'ExternalFile', 'FileSet', 'ScoreValue', 'File',
-                        'TechnicalAnalysis', 'QuestionnaireRun', 'Scan',
+                        'QuestionnaireRun', 'Scan',
                         'GenomicMeasure', 'ColumnRef', 'Answer', 'IHCMeasure', 'IHCResult',
                         'CghResult', 'Mutation', 'PETData', 'MRIData', 'DMRIData', 'Comment'])),
             cfg.structure(self.vreg.schema))
