@@ -18,7 +18,7 @@
 
 from cubicweb.web.action import Action
 from cubicweb.predicates import (is_instance, nonempty_rset, anonymous_user,
-                                 match_user_groups, relation_possible)
+                                 one_line_rset, match_user_groups, relation_possible)
 from cubicweb.web.views.actions import (CopyAction, ModifyAction, DeleteAction,
                                         ManagePermissionsAction, AddRelatedActions)
 
@@ -76,7 +76,7 @@ ManagePermissionsAction.icon = 'eye-open'
 ###############################################################################
 class BrainomicsAbstractDownloadAction(Action):
     __abstract__ = True
-    __select__ = Action.__select__ & nonempty_rset()
+    __select__ = Action.__select__ & nonempty_rset() & ~one_line_rset()
     category = 'download-links'
 
 
