@@ -17,16 +17,22 @@
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
 from logilab.mtconverter import xml_escape
+from logilab.common.registry import objectify_predicate
 
 from cubicweb import tags
+from cubicweb.utils import json_dumps
 from cubicweb.predicates import (none_rset, one_line_rset, is_instance, nonempty_rset,
                                  has_related_entities, match_view, match_user_groups,
                                  anonymous_user, relation_possible)
+
 from cubicweb.web import component
 from cubicweb.web.views import facets
 from cubicweb.web.views.boxes import EditBox
 from cubicweb.web.views.bookmark import BookmarksBox
 from cubicweb.web.views.basecomponents import ApplicationName, HeaderComponent
+from cubicweb.web.httpcache import NoHTTPCacheManager
+
+from cubes.bootstrap.views.basecomponents import AUSDropDownBox
 
 from cubes.brainomics.views.download import ALL_DOWNLOADABLE
 
@@ -35,9 +41,14 @@ LINKED_ENTITIES = ('Subject',)
 _ = unicode
 
 
-###############################################################################
-### NAVIGATION BOXES ##########################################################
-###############################################################################
+@objectify_predicate
+def has_dynamic_facets(cls, req, rset=None, **kwargs):
+    dfreg = req.vreg.get('dynamic-facet')
+    if dfreg and list(dfreg.possible_objects(req, rset=rset)):
+        return 1
+    return 0
+
+
 class BrainomicsLinksCtx(component.EntityCtxComponent):
     """ Component used to display related informations and links,
     referenced by the registry 'ctx-related-links'.
@@ -151,7 +162,6 @@ class BrainomicsLinksBrowse(BrainomicsLinksDropdown):
         possible_actions = self._cw.vreg['actions'].possible_actions(self._cw, self.cw_rset)
         links = set()
         for link in list(possible_actions.get('browse-links', [])):
-            print link.url()
             links.add((link.url(), link.title))
         return links
 
@@ -189,6 +199,58 @@ class BrainomicsEditBox(EditBox):
             w(u'</div>')
 
 
+class BrainomicsBookmarksBox(BookmarksBox, HeaderComponent):
+    """display a box containing all user's bookmarks"""
+    __regid__ = 'bookmarks_box'
+    context = _('header-right')
+    order = HeaderComponent.order
+
+    def render_action(self, url, title):
+        return u'<li><a href="%s" role="menuitem">%s</a></li>' % (url, title)
+
+    def render(self, w):
+        self.init_rendering()
+        req = self._cw
+        ueid = self._cw.user.eid
+        html = []
+        if self.can_delete:
+            req.add_js('cubicweb.ajax.js')
+        if self.can_edit:
+            # Create bookmark this page link
+            linkto = 'bookmarked_by:%s:subject' % ueid
+            path = req.relative_path()
+            url = req.vreg['etypes'].etype_class('Bookmark').cw_create_url(
+                req, __linkto=linkto, path=path)
+            html.append(self.render_action(url, req._('bookmark this page')))
+            # Edit bookmarks
+            if self.bookmarks_rset:
+                if req.user.is_in_group('managers'):
+                    bookmarksrql = 'Bookmark B WHERE B bookmarked_by U, U eid %s' % ueid
+                    erset = self.bookmarks_rset
+                else:
+                    bookmarksrql = ('Bookmark B WHERE B bookmarked_by U, '
+                                    'B owned_by U, U eid %(x)s')
+                    erset = req.execute(bookmarksrql, {'x': ueid},
+                                        build_descr=False)
+                    bookmarksrql %= {'x': ueid}
+                if erset:
+                    url = req.build_url(vid='muledit', rql=bookmarksrql)
+                    html.append(self.render_action(url, req._('edit bookmarks')))
+            # Pick bookmarks
+            url = req.user.absolute_url(vid='xaddrelation', rtype='bookmarked_by',
+                                        target='subject')
+            html.append(self.render_action(url, req._('pick existing bookmarks')))
+        # Add divided
+        html.append(u'<li class="divider"></li>')
+        # Add bookmarks
+        for bookmark in self.bookmarks_rset.entities():
+            html.append(self.render_action(bookmark.action_url(), bookmark.title))
+        # Render box
+        ddb = AUSDropDownBox(self._cw._('manage bookmarks'), u'\n'.join(html))
+        ddb.render(w=w)
+
+
+
 ###############################################################################
 ### DOWNLOAD BOX ##############################################################
 ###############################################################################
@@ -239,7 +301,7 @@ class BrainomicsResultsFileBox(component.CtxComponent):
         for _file in _files:
             title = _file.dc_title().rsplit('/')[-1]
             w(u'<li>%s<a href="%s" title="%s">%s</a></li>'
-              % (_file.view('icon'), _file.absolute_url(),
+              % (_file.view('icon'), _file.absolute_url(vid='download'),
                  xml_escape(title), xml_escape(title[:15]+'...')))
         w(u'</ul>')
         w(u'</div>')
@@ -253,16 +315,77 @@ class BrainomicsConfigurationFileBox(BrainomicsResultsFileBox):
     title = _('Configuration files')
     order = 3
 
+def filter_hiddens(w, baserql, wdgs, **kwargs):
+    # start brainomincs customization
+    for wdg in wdgs:
+        # we would probably like to dynamically add other facets elsewhere
+        w(u'<input type="hidden" name="facets" value="%s" />' % (
+            xml_escape(wdg.facet.__regid__)))
+    # end brainomincs customization
+    kwargs['baserql'] = baserql
+    for key, val in kwargs.items():
+        w(u'<input type="hidden" name="%s" value="%s" />' % (
+            key, xml_escape(val)))
 
-###############################################################################
-### FACETS/FORMWIDGETS ########################################################
-###############################################################################
-facets.FilterBox.bk_linkbox_template = u'<p class="btn btn-primary btn-facet">%s</p>'
+class BrainomicsFilterBox(facets.FilterBox):
+    http_cache_manager = NoHTTPCacheManager
+    bk_linkbox_template = u'<p class="btn btn-primary btn-facet">%s</p>'
+    __select__ = facets.FilterBox.__select__ | has_dynamic_facets()
+
+    def layout_widgets(self, w, wdgs):
+        super(BrainomicsFilterBox, self).layout_widgets(w, wdgs)
+        w(u'<div class="admintools">')
+        w(u'<div id="dynamic-facet-container"></div>')
+        for comp in self._cw.vreg['dynamic-facet'].possible_objects(self._cw, rset=self.cw_rset):
+            comp.render(w=w)
+        w(u'</div>')
+
+    def clean_dynamic_facets(self):
+        """ clean all dynamically created facets.
+        """
+        vreg = self._cw.vreg['facets']
+        facetids = [k for k, v in vreg.iteritems() if v and getattr(v[0], 'dynamic_facet', False)]
+        for facetid in facetids:
+            vreg.pop(facetid)
+
+    def generate_form(self, w, rset, divid, vid, vidargs=None, mainvar=None,
+                      paginate=False, cssclass='', hiddens=None, **kwargs):
+        kwargs.pop('context', None)
+        # clean dynamic-facet vreg : remove all previously dynamically created facets
+        self.clean_dynamic_facets()
+        # do not use the facets cache, recompute all facets
+        baserql, wdgs = facets._facets(self._cw, rset, context=self.__regid__,
+                                       mainvar=mainvar, **kwargs)
+        # Remove assert wdgs as now, we may have dynamic facets
+        self._cw.add_js(self.needs_js)
+        self._cw.add_css(self.needs_css)
+        self._cw.html_headers.define_var('facetLoadingMsg',
+                                         self._cw._('facet-loading-msg'))
+        vidargs = {}
+        vidargs = dict((k, v) for k, v in vidargs.iteritems() if v)
+        facetargs = xml_escape(json_dumps([divid, vid, paginate, vidargs]))
+        w(u'<form id="%sForm" class="%s" method="post" action="" '
+          'cubicweb:facetargs="%s" >' % (divid, cssclass, facetargs))
+        w(u'<fieldset>')
+        if hiddens is None:
+            hiddens = {}
+        if mainvar:
+            hiddens['mainvar'] = mainvar
+        filter_hiddens(w, baserql, wdgs, **hiddens)
+        self.layout_widgets(w, self.sorted_widgets(wdgs))
+        w(u'<input type="submit" class="hidden" />')
+        w(u'</fieldset>\n')
+        w(u'</form>\n')
 
 
 def registration_callback(vreg):
-    vreg.register_all(globals().values(), __name__, (BrainomicsEditBox,))
+    vreg.register_all(globals().values(), __name__, (BrainomicsEditBox,
+                                                     BrainomicsFilterBox,
+                                                     BrainomicsBookmarksBox))
     vreg.register_and_replace(BrainomicsEditBox, EditBox)
+    vreg.register_and_replace(BrainomicsBookmarksBox, BookmarksBox)
+    vreg.register_and_replace(BrainomicsFilterBox, facets.FilterBox)
+
     # Unregister breadcrumbs
     from cubicweb.web.views.ibreadcrumbs import (BreadCrumbEntityVComponent,
                                                  BreadCrumbLinkToVComponent,
