@@ -22,83 +22,81 @@ from cubicweb.selectors import is_instance
 from cubicweb.web.views.tableview import (TableLayout, EntityTableView,
                                           RelationColRenderer, EntityTableColRenderer)
 
+from cubes.brainomics.views.slickgrid import SlickGridEntityTableView
+
+_ = unicode
+
 
-###############################################################################
-### TABLE LAYOUT ##############################################################
-###############################################################################
 class FilterTableLayout(TableLayout):
     __regid__ = 'filter_table_layout'
     display_filter = 'top'
     hide_filter = False
 
 
-###############################################################################
-### GENOMIC MEASURE - CGH #####################################################
-###############################################################################
 def render_width(w, entity):
     w(unicode(entity.genomic_region[0].width))
 
-class AbstractCghTableView(EntityTableView):
+
+class AbstractCghTableView(SlickGridEntityTableView, EntityTableView):
     __abtract__ = True
-    layout_id = 'filter_table_layout'
     paginable = False
     __select__ = EntityTableView.__select__ & is_instance('CghResult')
+    columns = ['cgh_ratio', 'log2_ratio', 'status', 'width', 'numprobes']
+    column_renderers = {'width':  EntityTableColRenderer(renderfunc=render_width)}
+    grid_options = {'enableCellNavigation': True, 'frozenColumn': 0}
+    default_column_options = {'sortable': True, 'width': 140,}
+
 
 
 class CghTableView(AbstractCghTableView):
     __regid__ = 'genmeas-table-view'
-    layout_id = 'filter_table_layout'
-    columns = ['genomic_region', 'cgh_ratio', 'log2_ratio', 'width', 'status', 'numprobes']
-    column_renderers = {'genomic_region': RelationColRenderer(role='subject'),
-                        'width':  EntityTableColRenderer(renderfunc=render_width)}
+    columns = ['genomic_region',] + AbstractCghTableView.columns
+    AbstractCghTableView.column_renderers.update({'genomic_region':
+                                                  RelationColRenderer(role='subject')})
 
 
 
 class GeneCghTableView(AbstractCghTableView):
     __regid__ = 'gene-genmeas-table-view'
-    columns = ['genomic_region', 'related_measure', 'cgh_ratio', 'log2_ratio', 'width', 'status']
-    column_renderers = {'related_measure': RelationColRenderer(role='subject', vid='incontext'),
-                        'genomic_region': RelationColRenderer(role='subject', vid='incontext'),
-                        'width':  EntityTableColRenderer(renderfunc=render_width)}
+    columns = ['genomic_region', 'related_measure'] + AbstractCghTableView.columns
+    AbstractCghTableView.column_renderers.update({'related_measure':
+                                                  RelationColRenderer(role='subject',
+                                                                      vid='incontext'),
+                                                  'genomic_region':
+                                                  RelationColRenderer(role='subject',
+                                                                      vid='incontext')})
 
 
-class RegionCghTableView(EntityTableView):
+class RegionCghTableView(AbstractCghTableView):
     __regid__ = 'region-genmeas-table-view'
-    columns = ['related_measure', 'cgh_ratio', 'log2_ratio', 'status']
-    column_renderers = {'related_measure': RelationColRenderer(role='subject', vid='incontext')}
+    columns = ['related_measure',] + AbstractCghTableView.columns
+    AbstractCghTableView.column_renderers.update({'related_measure':
+                                                  RelationColRenderer(role='subject',
+                                                                      vid='incontext')})
 
 
-###############################################################################
-### GENOMIC MEASURE - SEQUENCAGE ##############################################
-###############################################################################
-class AbstractMutationTableView(EntityTableView):
+class AbstractMutationTableView(SlickGridEntityTableView, EntityTableView):
     __abstract__ = True
-    layout_id = 'filter_table_layout'
     paginable = False
     __select__ = EntityTableView.__select__ & is_instance('Mutation')
 
-    columns = ['valid', 'mutation_id', 'mutation_type', 'ploidy',
-               'reference_base', 'variant_base', 'variant_frequency', 'p_value',
-               'coverage', 'reference_coverage', 'variant_coverage',
-               'hotspot_id', 'reference_id', 'comment',
-               'protein', 'biological_classification', 'classification_type',
-               'locus_version', 'nucl', 'polyphen', 'sift', 'gvd_alignment',
-               'base', 'conclusions', 'medical_coverage']
+    columns = ['conclusions', 'position_in_gene',
+               'mutation_type', 'amplicon', 'protein',
+               'classification_type', 'variant_frequency',
+               'reference_base', 'variant_base', 'variant_coverage', 'coverage',
+               'reference_id', 'dbsnp', 'locus_version', 'nucl',
+               'sift', 'polyphen', 'classification_variant']
 
 
 class MutationTableView(AbstractMutationTableView):
     __regid__ = 'genmeas-table-view'
-
-    column_renderers = {'related_gene': RelationColRenderer(role='subject')}
-
+    column_renderers = {'related_gene': RelationColRenderer(role='subject', vid='incontext')}
     columns = ['related_gene',] + AbstractMutationTableView.columns
 
 
 class GeneMutationTableView(AbstractMutationTableView):
     __regid__ = 'gene-genmeas-table-view'
-
     column_renderers = {'related_measure': RelationColRenderer(role='subject', vid='incontext')}
-
     columns = ['related_measure',] + AbstractMutationTableView.columns
 
 
@@ -124,12 +122,7 @@ class ScoreValueInContextTableView(EntityTableView):
         w(u'<ul>%s</ul>' % (entity.datetime or u'-'))
 
     def render_target(w, entity):
-        if entity.reverse_related_infos:
-            w(u'<ul>%s</ul>' % ''.join(u'<li>%s</li>' % e.view('incontext') for
-                                       e in entity.reverse_related_infos))
-        elif entity.measure:
-            w(u'<ul>%s</ul>' % ''.join(u'<li>%s</li>' % m.concerns[0].view('incontext')
-                                       for m in entity.measure))
+        w(u'%s' % entity.subject.view('incontext'))
 
     columns = ['subject', 'value', 'datetime']
     column_renderers = {'datetime': EntityTableColRenderer(renderfunc=render_datetime),
@@ -140,14 +133,16 @@ class ScoreValueInContextTableView(EntityTableView):
 ###############################################################################
 ### DRUG TAKES ################################################################
 ###############################################################################
-class AbstractDrugTakeTableView(EntityTableView):
+class AbstractDrugTakeTableView(SlickGridEntityTableView):
     __abstract__ = True
     paginable = False
     __select__ = EntityTableView.__select__ & is_instance('DrugTake')
-
+    grid_options = {'enableCellNavigation': True, 'frozenColumn': 0}
+    default_column_options = {'sortable': True, 'width': 140,}
     columns = ['drug']
     column_renderers = {'drug': RelationColRenderer(role='subject', vid='incontext')}
 
+
 class InTherapyDrugTakeTableView(AbstractDrugTakeTableView):
     __regid__ = 'intherapy-drugtake-table-view'
 
@@ -156,6 +151,7 @@ class InTherapyDrugTakeTableView(AbstractDrugTakeTableView):
                 'take_order', 'dosis', 'unit', 'number_of_cycles', 'dosis_percentage',
                 'reduced_dosis'])
 
+
 class DrugTakeTableView(AbstractDrugTakeTableView):
     __regid__ = 'drugtake-table-view'
 
@@ -246,10 +242,17 @@ class TechnicalAnalysisTableView(EntityTableView):
     __select__ = EntityTableView.__select__ & is_instance('TechnicalAnalysis')
     __regid__ = 'analysis-table-view'
 
-    columns = ['protocols', 'technique_type', 'results', 'conclusion', 'analysis_date', 'performed_on']
+    def render_analysis_on(w, entity):
+        if entity.performed_on:
+            return entity.performed_on[0].view('incontext')
+        elif entity.analysis_of_sample:
+            return entity.analysis_of_sample[0].view('incontext')
+
+    columns = ['protocols', 'technique_type', 'results', 'conclusion',
+               'analysis_date', _('analysis_on')]
     column_renderers = {'protocols': RelationColRenderer(role='subject', vid='incontext'),
                         'technique_type': RelationColRenderer(role='subject', vid='incontext'),
-                        'performed_on': RelationColRenderer(role='subject', vid='incontext'),
+                        'analysis_on': EntityTableColRenderer(renderfunc=render_analysis_on)
                        }
 
 
