@@ -4,6 +4,7 @@ from itertools import chain
 
 from logilab.common.date import ustrftime
 
+from cubicweb.utils import json_dumps
 from cubicweb.predicates import is_instance
 
 try:
@@ -12,9 +13,15 @@ except ImportError:
     pass
 else:
     class SubjectVeriteCoTimelineView(VeriteCoTimelineView):
-        __regid__ = 'vtimeline'
         __select__ = is_instance('Subject')
 
+        def js_story_factory(self, settings):
+            return u'''$("a[href$=\'#entity-timeline-tab\']").on('shown.bs.tab', function() {
+            if (cw.cubes.brainomics.timelineLoaded === undefined) {
+                createStoryJS(%s);
+                cw.cubes.brainomics.timelineLoaded = true;}});
+            ''' % json_dumps(settings)
+
 
     class VeriteCoTimelineJsonDataView(VeriteCoTimelineJsonDataView):
         __select__ = is_instance('Subject')
